========
*pygcal*
========

.. image:: https://img.shields.io/pypi/v/pygcal

.. image:: https://img.shields.io/github/license/veltzer/pygcal

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pygcal

author: Mark Veltzer

version: 0.0.4

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2025
